@@ -75,7 +75,7 @@ if environ.get("CURVENOTE_ENV") == "development":
     print(f"Accessing API at: {API_URL}")
     SITE_URL = "https://localhost:3000"
 else:
-    API_URL = "https://api.curvenote.com"
+    API_URL = environ.get("CURVENOTE_API", "https://api.curvenote.com")
     SITE_URL = "https://curvenote.com"
 ME_URL = "{api_url}/my/user"
 USERS_URL = "{api_url}/users/{user_id}"
