@@ -1,3 +1,5 @@
+from typing import Union
+from curvenote.models import Project
 import logging
 import os
 
@@ -28,7 +30,7 @@ class LatexProject:
     @classmethod
     def build_single_article(cls,
         session: Session, target_folder: str,
-        project_id: str, article_id: str, version: int):
+        project_id: Union[str, Project], article_id: str, version: int):
         latex_project = cls(session, target_folder)
         try:
             latex_project.add_article(project_id, article_id, version)
@@ -64,14 +66,21 @@ class LatexProject:
             loader=PackageLoader("curvenote", "latex/templates"),
         )
 
-    def add_article(self, project_id: str, article_id: str, version: int):
+    def add_article(self, project_id: Union[str, Project], article_id: str, version: int):
+        logging.info("add_article")
         latex_article = LatexArticle(self.session, project_id, article_id)
+        logging.info("created article")
         latex_article.fetch(version)
+        logging.info("fetch conplete")
         latex_article.localize(self.session, self.assets_folder, self.reference_list)
+        logging.info("localize complete")
 
         idx = len(self.articles)
+        logging.info(f"number of articles {idx}")
         filename = f"{idx}_{latex_article.block.name}"
+        logging.info(f"generate filename {filename}")
         self.articles.append((f"documents/{filename}", latex_article, filename))
+        logging.info(f"appended article documents/{filename}")
 
     def render(self):
         template = self.jinja.get_template("index.tpl")
